@@ -9,7 +9,7 @@ use alloc::{string::String, vec, vec::Vec};
 #[cfg(feature = "std")]
 use std::{io, string::String, vec, vec::Vec};
 
-/// Deserializes an instance of `T` from the bytes of an `io::Read` type.
+/// Deserializes an instance of `T` from the bytes of an [`io::Read`] type.
 ///
 /// # Errors
 ///
@@ -44,14 +44,14 @@ where
 }
 
 #[derive(Debug)]
-/// A `Bencode` Deserializer for types which implement `Deserialize`.
+/// A `Bencode` Deserializer for types which implement [Deserialize][serde::de::Deserialize].
 pub struct Deserializer<R> {
     read: R,
 }
 
-impl<'de, R> Deserializer<R>
+impl<R> Deserializer<R>
 where
-    R: read::Read<'de>,
+    R: Read,
 {
     /// Constructs a Deserializer from a readable source.
     pub fn new(read: R) -> Self {
@@ -177,7 +177,7 @@ where
         let len = self.parse_bytes_len()?;
         let mut buf = vec![0u8; len];
         for i in &mut buf {
-            *i = self.parse_next()?
+            *i = self.parse_next()?;
         }
         Ok(buf)
     }
@@ -241,7 +241,7 @@ where
                 b'i' => self.capture_integer(buf)?,
                 b'l' => self.capture_list(buf)?,
                 b'd' => self.capture_dict(buf)?,
-                _ => return Err(Error::InvalidDict),
+                _ => return Err(Error::InvalidList),
             }
         }
     }
@@ -279,7 +279,8 @@ impl<R> Deserializer<read::IoRead<R>>
 where
     R: io::Read,
 {
-    /// Constructs a Deserializer from an `io::IoRead` source.
+    /// Constructs a Deserializer from an [`std::io::Read`][std::io::Read] source.
+    #[must_use]
     pub fn from_reader(reader: R) -> Self {
         Deserializer::new(read::IoRead::new(reader))
     }
@@ -287,6 +288,7 @@ where
 
 impl<'a> Deserializer<read::SliceRead<'a>> {
     /// Constructs a Deserializer from a `&[u8]`.
+    #[must_use]
     pub fn from_slice(bytes: &'a [u8]) -> Self {
         Deserializer::new(read::SliceRead::new(bytes))
     }
@@ -314,7 +316,7 @@ macro_rules! forward_deserialize_unsigned_integer {
     };
 }
 
-impl<'de, 'a, R: Read<'de>> de::Deserializer<'de> for &'a mut Deserializer<R> {
+impl<'de, 'a, R: Read> de::Deserializer<'de> for &'a mut Deserializer<R> {
     type Error = Error;
 
     #[inline]
@@ -551,7 +553,7 @@ impl<'de, 'a, R: Read<'de>> de::Deserializer<'de> for &'a mut Deserializer<R> {
 }
 
 #[derive(Debug)]
-struct SeqAccess<'a, R: 'a> {
+struct SeqAccess<'a, R> {
     de: &'a mut Deserializer<R>,
 }
 
@@ -561,7 +563,7 @@ impl<'a, R: 'a> SeqAccess<'a, R> {
     }
 }
 
-impl<'de, 'a, R: Read<'de> + 'a> de::SeqAccess<'de> for SeqAccess<'a, R> {
+impl<'de, 'a, R: Read + 'a> de::SeqAccess<'de> for SeqAccess<'a, R> {
     type Error = Error;
 
     fn next_element_seed<T>(&mut self, seed: T) -> Result<Option<T::Value>>
@@ -576,7 +578,7 @@ impl<'de, 'a, R: Read<'de> + 'a> de::SeqAccess<'de> for SeqAccess<'a, R> {
 }
 
 #[derive(Debug)]
-struct MapAccess<'a, R: 'a> {
+struct MapAccess<'a, R> {
     de: &'a mut Deserializer<R>,
 }
 
@@ -586,7 +588,7 @@ impl<'a, R: 'a> MapAccess<'a, R> {
     }
 }
 
-impl<'de, 'a, R: Read<'de> + 'a> de::MapAccess<'de> for MapAccess<'a, R> {
+impl<'de, 'a, R: Read + 'a> de::MapAccess<'de> for MapAccess<'a, R> {
     type Error = Error;
 
     fn next_key_seed<K>(&mut self, seed: K) -> Result<Option<K::Value>>
@@ -609,13 +611,13 @@ impl<'de, 'a, R: Read<'de> + 'a> de::MapAccess<'de> for MapAccess<'a, R> {
 }
 
 #[derive(Debug)]
-struct MapKey<'a, R: 'a> {
+struct MapKey<'a, R> {
     de: &'a mut Deserializer<R>,
 }
 
 impl<'de, 'a, R> de::Deserializer<'de> for MapKey<'a, R>
 where
-    R: Read<'de>,
+    R: Read,
 {
     type Error = Error;
 
