@@ -1,4 +1,4 @@
-//! Serializes into a `Value`.
+//! Serializes into a [Value].
 
 use super::{Number, Value};
 use crate::error::{Error, Result};
@@ -10,12 +10,14 @@ use alloc::{collections::BTreeMap, vec::Vec};
 #[cfg(feature = "std")]
 use std::{collections::BTreeMap, vec::Vec};
 
-/// Serializes an instance of `T` into a `Value`.
+/// Serializes an instance of `T` into a [Value].
 ///
 /// # Errors
 ///
-/// Serialization can fail if `T`'s implementation of `Serialize` decides to fail, if `T` contains
-/// unsupported types for serialization, or if `T` contains a map with non-string keys.
+/// Serialization can fail if `T`'s implementation of
+/// [Serialize][serde::ser::Serialize] decides to fail, if `T` contains
+/// unsupported types for serialization, or if `T` contains a map with
+/// non-string keys.
 #[inline]
 pub fn to_value<T>(value: &T) -> Result<Value>
 where
@@ -398,7 +400,7 @@ impl ser::Serializer for &mut DictKeySerializer {
         Err(Error::UnsupportedType)
     }
 
-    fn serialize_newtype_struct<T: ?Sized + ser::Serialize>(
+    fn serialize_newtype_struct<T: ?Sized + Serialize>(
         self,
         _name: &'static str,
         _value: &T,
@@ -406,7 +408,7 @@ impl ser::Serializer for &mut DictKeySerializer {
         Err(Error::UnsupportedType)
     }
 
-    fn serialize_newtype_variant<T: ?Sized + ser::Serialize>(
+    fn serialize_newtype_variant<T: ?Sized + Serialize>(
         self,
         _name: &'static str,
         _variant_index: u32,
@@ -420,7 +422,7 @@ impl ser::Serializer for &mut DictKeySerializer {
         Err(Error::UnsupportedType)
     }
 
-    fn serialize_some<T: ?Sized + ser::Serialize>(self, _value: &T) -> Result<Self::Ok> {
+    fn serialize_some<T: ?Sized + Serialize>(self, _value: &T) -> Result<Self::Ok> {
         Err(Error::UnsupportedType)
     }
 
@@ -635,7 +637,7 @@ mod tests {
         use serde::Serializer;
 
         assert!(matches!(
-            super::Serializer.serialize_unit_struct("Nothing"),
+            Serializer.serialize_unit_struct("Nothing"),
             Err(Error::UnsupportedType)
         ));
     }
@@ -645,7 +647,7 @@ mod tests {
         use serde::Serializer;
 
         assert!(matches!(
-            super::Serializer.serialize_unit_variant("Nothing", 0, "Case"),
+            Serializer.serialize_unit_variant("Nothing", 0, "Case"),
             Err(Error::UnsupportedType)
         ));
     }
@@ -654,9 +656,7 @@ mod tests {
     fn test_serialize_newtype_struct() {
         use serde::Serializer;
 
-        assert!(super::Serializer
-            .serialize_newtype_struct("Nothing", &2)
-            .is_ok());
+        assert!(Serializer.serialize_newtype_struct("Nothing", &2).is_ok());
     }
 
     #[test]
@@ -664,7 +664,7 @@ mod tests {
         use serde::Serializer;
 
         assert!(matches!(
-            super::Serializer.serialize_unit_variant("Nothing", 0, "Case"),
+            Serializer.serialize_unit_variant("Nothing", 0, "Case"),
             Err(Error::UnsupportedType)
         ));
     }
@@ -693,7 +693,7 @@ mod tests {
         use serde::Serializer;
 
         assert!(matches!(
-            super::Serializer.serialize_tuple(0),
+            Serializer.serialize_tuple(0),
             Err(Error::UnsupportedType)
         ));
     }
@@ -703,7 +703,7 @@ mod tests {
         use serde::Serializer;
 
         assert!(matches!(
-            super::Serializer.serialize_tuple_struct("Tuple Struct", 2),
+            Serializer.serialize_tuple_struct("Tuple Struct", 2),
             Err(Error::UnsupportedType)
         ));
     }
@@ -713,7 +713,7 @@ mod tests {
         use serde::Serializer;
 
         assert!(matches!(
-            super::Serializer.serialize_tuple_variant("Tuple Variant", 2, "Case", 1),
+            Serializer.serialize_tuple_variant("Tuple Variant", 2, "Case", 1),
             Err(Error::UnsupportedType)
         ));
     }
@@ -723,7 +723,7 @@ mod tests {
         use serde::Serializer;
 
         assert!(matches!(
-            super::Serializer.serialize_struct_variant("Struct Variant", 2, "Case", 1),
+            Serializer.serialize_struct_variant("Struct Variant", 2, "Case", 1),
             Err(Error::UnsupportedType)
         ));
     }
